@@ -9,34 +9,34 @@ class CollectionAdminBase(UploadedFileBase):
         info = self.model._meta.app_label, self.model._meta.model_name
         urlpatterns = [
             path(
-                'create/',
+                "create/",
                 self.admin_site.admin_view(views.collection.CreateCollectionView.as_view()),
-                name='%s_%s_create' % info,
+                name="%s_%s_create" % info,
             ),
             path(
-                'delete/',
+                "delete/",
                 self.admin_site.admin_view(views.collection.DeleteCollectionView.as_view()),
-                name='%s_%s_delete' % info,
+                name="%s_%s_delete" % info,
             ),
             path(
-                'upload_item/',
+                "upload_item/",
                 self.admin_site.admin_view(views.collection.UploadFileView.as_view()),
-                name='%s_%s_upload_item' % info,
+                name="%s_%s_upload_item" % info,
             ),
             path(
-                'delete_item/',
+                "delete_item/",
                 self.admin_site.admin_view(views.collection.DeleteFileView.as_view()),
-                name='%s_%s_delete_item' % info,
+                name="%s_%s_delete_item" % info,
             ),
             path(
-                'change_item/',
+                "change_item/",
                 self.admin_site.admin_view(views.collection.ChangeFileView.as_view()),
-                name='%s_%s_change_item' % info,
+                name="%s_%s_change_item" % info,
             ),
             path(
-                'sort_items/',
+                "sort_items/",
                 self.admin_site.admin_view(views.collection.SortItemsView.as_view()),
-                name='%s_%s_sort_items' % info,
+                name="%s_%s_sort_items" % info,
             ),
         ]
         return urlpatterns
