@@ -1,4 +1,5 @@
 from django import forms
+
 from ...models.image import UploadedImage
 from .base import UploadedFileBaseForm
 
@@ -6,9 +7,9 @@ from .base import UploadedFileBaseForm
 class UploadedImageDialog(UploadedFileBaseForm):
     class Meta:
         model = UploadedImage
-        fields = ('new_name', 'title', 'description')
+        fields = ("new_name", "title", "description")
         widgets = {
-            'description': forms.Textarea(attrs={
-                'rows': 3
+            "description": forms.Textarea(attrs={
+                "rows": 3
             })
         }
